# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/installations/v1/installations_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"6\n\x16GetInstallationRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"d\n\x17GetInstallationResponse\x12I\n\x0cinstallation\x18\x01 \x01(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02\"\x1a\n\x18ListInstallationsRequest\"g\n\x19ListInstallationsResponse\x12J\n\rinstallations\x18\x01 \x03(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02\"8\n\x1dGetProjectInstallationRequest\x12\x17\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\">\n\x1eGetProjectInstallationResponse\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x32\xcc\x03\n\x14InstallationsService\x12\x86\x01\n\x0fGetInstallation\x12\x38.strmprivacy.api.installations.v1.GetInstallationRequest\x1a\x39.strmprivacy.api.installations.v1.GetInstallationResponse\x12\x8c\x01\n\x11ListInstallations\x12:.strmprivacy.api.installations.v1.ListInstallationsRequest\x1a;.strmprivacy.api.installations.v1.ListInstallationsResponse\x12\x9b\x01\n\x16GetProjectInstallation\x12?.strmprivacy.api.installations.v1.GetProjectInstallationRequest\x1a@.strmprivacy.api.installations.v1.GetProjectInstallationResponseBx\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')



_GETINSTALLATIONREQUEST = DESCRIPTOR.message_types_by_name['GetInstallationRequest']
_GETINSTALLATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetInstallationResponse']
_LISTINSTALLATIONSREQUEST = DESCRIPTOR.message_types_by_name['ListInstallationsRequest']
_LISTINSTALLATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListInstallationsResponse']
_GETPROJECTINSTALLATIONREQUEST = DESCRIPTOR.message_types_by_name['GetProjectInstallationRequest']
_GETPROJECTINSTALLATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetProjectInstallationResponse']
GetInstallationRequest = _reflection.GeneratedProtocolMessageType('GetInstallationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLATIONREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstallationRequest)
  })
_sym_db.RegisterMessage(GetInstallationRequest)

GetInstallationResponse = _reflection.GeneratedProtocolMessageType('GetInstallationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLATIONRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstallationResponse)
  })
_sym_db.RegisterMessage(GetInstallationResponse)

ListInstallationsRequest = _reflection.GeneratedProtocolMessageType('ListInstallationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLATIONSREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstallationsRequest)
  })
_sym_db.RegisterMessage(ListInstallationsRequest)

ListInstallationsResponse = _reflection.GeneratedProtocolMessageType('ListInstallationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLATIONSRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstallationsResponse)
  })
_sym_db.RegisterMessage(ListInstallationsResponse)

GetProjectInstallationRequest = _reflection.GeneratedProtocolMessageType('GetProjectInstallationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTINSTALLATIONREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetProjectInstallationRequest)
  })
_sym_db.RegisterMessage(GetProjectInstallationRequest)

GetProjectInstallationResponse = _reflection.GeneratedProtocolMessageType('GetProjectInstallationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTINSTALLATIONRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetProjectInstallationResponse)
  })
_sym_db.RegisterMessage(GetProjectInstallationResponse)

_INSTALLATIONSSERVICE = DESCRIPTOR.services_by_name['InstallationsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._options = None
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._serialized_options = b'\340A\002'
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._options = None
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._options = None
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLATIONREQUEST._serialized_start=178
  _GETINSTALLATIONREQUEST._serialized_end=232
  _GETINSTALLATIONRESPONSE._serialized_start=234
  _GETINSTALLATIONRESPONSE._serialized_end=334
  _LISTINSTALLATIONSREQUEST._serialized_start=336
  _LISTINSTALLATIONSREQUEST._serialized_end=362
  _LISTINSTALLATIONSRESPONSE._serialized_start=364
  _LISTINSTALLATIONSRESPONSE._serialized_end=467
  _GETPROJECTINSTALLATIONREQUEST._serialized_start=469
  _GETPROJECTINSTALLATIONREQUEST._serialized_end=525
  _GETPROJECTINSTALLATIONRESPONSE._serialized_start=527
  _GETPROJECTINSTALLATIONRESPONSE._serialized_end=589
  _INSTALLATIONSSERVICE._serialized_start=592
  _INSTALLATIONSSERVICE._serialized_end=1052
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/entities/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/entities/v1/entities_v1.proto\x12\x1bstrmprivacy.api.entities.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1agoogle/type/datetime.proto\"\xcf\x03\n\x06Stream\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x16\n\x0e\x63onsent_levels\x18\x03 \x03(\x05\x12I\n\x12\x63onsent_level_type\x18\x04 \x01(\x0e\x32-.strmprivacy.api.entities.v1.ConsentLevelType\x12\x14\n\x07\x65nabled\x18\x05 \x01(\x08\x42\x03\xe0\x41\x03\x12\x38\n\x06limits\x18\x06 \x01(\x0b\x32#.strmprivacy.api.entities.v1.LimitsB\x03\xe0\x41\x03\x12\x15\n\rlinked_stream\x18\x07 \x01(\t\x12\x0c\n\x04tags\x18\x08 \x03(\t\x12\x42\n\x0b\x63redentials\x18\t \x03(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsB\x03\xe0\x41\x03\x12@\n\rmasked_fields\x18\n \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFields\x12\x18\n\x0bkafka_topic\x18\x0b \x01(\tB\x03\xe0\x41\x03\"v\n\x0e\x45xtendedStream\x12\x33\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Stream\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x0c\n\x04uuid\x18\x03 \x01(\t\x12\x12\n\nkey_stream\x18\x04 \x01(\x08\"\x9f\x01\n\x13\x45xtendedStreamGroup\x12\x42\n\rsource_stream\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStream\x12\x44\n\x0f\x64\x65rived_streams\x18\x02 \x03(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStream\"\x99\x02\n\x0cMaskedFields\x12\x11\n\thash_type\x18\x01 \x01(\t\x12\x0c\n\x04seed\x18\x02 \x01(\t\x12T\n\x0e\x66ield_patterns\x18\x03 \x03(\x0b\x32<.strmprivacy.api.entities.v1.MaskedFields.FieldPatternsEntry\x1ak\n\x12\x46ieldPatternsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x44\n\x05value\x18\x02 \x01(\x0b\x32\x35.strmprivacy.api.entities.v1.MaskedFields.PatternList:\x02\x38\x01\x1a%\n\x0bPatternList\x12\x16\n\x0e\x66ield_patterns\x18\x01 \x03(\t\";\n\x06Limits\x12\x17\n\nevent_rate\x18\x01 \x01(\x03\x42\x03\xe0\x41\x03\x12\x18\n\x0b\x65vent_count\x18\x02 \x01(\x03\x42\x03\xe0\x41\x03\"w\n\tKeyStream\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x03\xe0\x41\x02\x12\x13\n\x06status\x18\x02 \x01(\tB\x03\xe0\x41\x03\x12\x18\n\x0bkafka_topic\x18\x03 \x01(\tB\x03\xe0\x41\x03\"O\n\tStreamRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"R\n\x0cKeyStreamRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"r\n\x0b\x43redentials\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x16\n\tclient_id\x18\x02 \x01(\tB\x03\xe0\x41\x03\x12\x1a\n\rclient_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03\x12\x17\n\nproject_id\x18\x04 \x01(\tB\x03\xe0\x41\x03\"\xc8\x01\n\x04Sink\x12\x36\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02\x12=\n\tsink_type\x18\x02 \x01(\x0e\x32%.strmprivacy.api.entities.v1.SinkTypeB\x03\xe0\x41\x02\x12;\n\x06\x62ucket\x18\x04 \x01(\x0b\x32).strmprivacy.api.entities.v1.BucketConfigH\x00:\x02\x18\x01\x42\x08\n\x06\x63onfig\"9\n\x07SinkRef\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02:\x02\x18\x01\"[\n\x0c\x42ucketConfig\x12\x18\n\x0b\x62ucket_name\x18\x04 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x63redentials\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\x0f\x61ssume_role_arn\x18\x06 \x01(\t\"\xd3\x03\n\rDataConnector\x12:\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRef\x12\x45\n\ts3_bucket\x18\x02 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.AwsS3BucketLocationH\x00\x12\x64\n\x1bgoogle_cloud_storage_bucket\x18\x03 \x01(\x0b\x32=.strmprivacy.api.entities.v1.GoogleCloudStorageBucketLocationH\x00\x12\x66\n\x1c\x61zure_blob_storage_container\x18\x04 \x01(\x0b\x32>.strmprivacy.api.entities.v1.AzureBlobStorageContainerLocationH\x00\x12\x0c\n\x04uuid\x18\x05 \x01(\t\x12W\n\x12\x64\x65pendent_entities\x18\x06 \x01(\x0b\x32;.strmprivacy.api.entities.v1.DataConnectorDependentEntitiesB\n\n\x08location\"L\n\x10\x44\x61taConnectorRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\"\xa0\x01\n\x1e\x44\x61taConnectorDependentEntities\x12\x43\n\x0f\x62\x61tch_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\x12\x39\n\nbatch_jobs\x18\x02 \x03(\x0b\x32%.strmprivacy.api.entities.v1.BatchJob\"g\n\x13\x41wsS3BucketLocation\x12\x18\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x63redentials\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x1c\n\x0f\x61ssume_role_arn\x18\x03 \x01(\tB\x03\xe0\x41\x01\"V\n GoogleCloudStorageBucketLocation\x12\x18\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x63redentials\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\xc3\x01\n!AzureBlobStorageContainerLocation\x12 \n\x13storage_account_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1b\n\x0e\x63ontainer_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12_\n\x18\x63lient_secret_credential\x18\x03 \x01(\x0b\x32\x38.strmprivacy.api.entities.v1.AzureClientSecretCredentialB\x03\xe0\x41\x02\"i\n\x1b\x41zureClientSecretCredential\x12\x16\n\ttenant_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tclient_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x1a\n\rclient_secret\x18\x03 \x01(\tB\x03\xe0\x41\x02\"N\n\x08\x44\x61taType\x12\x35\n\x03\x63sv\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.CsvConfigH\x00\x42\x0b\n\tdata_type\"\x1c\n\tCsvConfig\x12\x0f\n\x07\x63harset\x18\x01 \x01(\t\"\xc4\x03\n\rBatchExporter\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02\x12\x41\n\nstream_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02H\x00\x12H\n\x0ekey_stream_ref\x18\x03 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x03\xe0\x41\x02H\x00\x12\x30\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x03\xe0\x41\x02\x12\x16\n\tsink_name\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0bpath_prefix\x18\x06 \x01(\t\x12\x1f\n\x17include_existing_events\x18\x07 \x01(\x08\x12I\n\x12\x64\x61ta_connector_ref\x18\x08 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x1a\n\x18stream_or_key_stream_ref\"r\n\x15\x45xtendedBatchExporter\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12<\n\x08\x65xporter\x18\x03 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\"V\n\x10\x42\x61tchExporterRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\xca\x01\n\x0cKafkaCluster\x12>\n\x03ref\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02\x12\x1e\n\x11\x62ootstrap_servers\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12G\n\x0e\x61uth_mechanism\x18\x03 \x01(\x0e\x32*.strmprivacy.api.entities.v1.AuthMechanismB\x03\xe0\x41\x02\x12\x11\n\ttoken_uri\x18\x04 \x01(\t\"U\n\x0fKafkaClusterRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x8f\x02\n\rKafkaExporter\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x03\xe0\x41\x02\x12?\n\nstream_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02\x12\x45\n\x06target\x18\x03 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.KafkaExporterTargetB\x03\xe0\x41\x02\x12\x35\n\x05users\x18\x04 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser\"V\n\x10KafkaExporterRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x9b\x01\n\x13KafkaExporterTarget\x12\x46\n\x0b\x63luster_ref\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02\x12\x12\n\x05topic\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x15\n\rclient_secret\x18\x04 \x01(\t\"\xfa\x01\n\tKafkaUser\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x03\xe0\x41\x02\x12 \n\x13kafka_exporter_name\x18\x03 \x01(\tB\x03\xe0\x41\x03\x12\x12\n\x05topic\x18\x04 \x01(\tB\x03\xe0\x41\x03\x12\x16\n\tclient_id\x18\x05 \x01(\tB\x03\xe0\x41\x03\x12\x1a\n\rclient_secret\x18\x06 \x01(\tB\x03\xe0\x41\x03\x12\x46\n\x0b\x63luster_ref\x18\x07 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x03\"R\n\x0cKafkaUserRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x03\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\'\n\rConsentLevels\x12\x16\n\x0e\x63onsent_levels\x18\x01 \x03(\x05\"o\n\x13\x43onsentLevelMapping\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\"]\n\x16\x43onsentLevelMappingRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x12\n\x05level\x18\x02 \x01(\x05\x42\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\x96\x01\n\x12WindowedEventCount\x12\x33\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x31\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x18\n\x0b\x65vent_count\x18\x03 \x01(\x03\x42\x03\xe0\x41\x03\"\x8c\x01\n\tSchemaRef\x12\x13\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x41\n\x0bschema_type\x18\x04 \x01(\x0e\x32\'.strmprivacy.api.entities.v1.SchemaTypeB\x03\xe0\x41\x03\"\xd3\x04\n\x06Schema\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12=\n\x05state\x18\x02 \x01(\x0e\x32).strmprivacy.api.entities.v1.Schema.StateB\x03\xe0\x41\x03\x12\x11\n\tis_public\x18\x03 \x01(\x08\x12\x17\n\ndefinition\x18\x04 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x66ingerprint\x18\x05 \x01(\tB\x03\xe0\x41\x03\x12=\n\x08metadata\x18\x06 \x01(\x0b\x32+.strmprivacy.api.entities.v1.SchemaMetadata\x12Q\n\rsimple_schema\x18\x07 \x01(\x0b\x32:.strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinition\x12\n\n\x02id\x18\x08 \x01(\t\x1a\x97\x01\n\x16SimpleSchemaDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12<\n\x05nodes\x18\x04 \x03(\x0b\x32-.strmprivacy.api.entities.v1.SimpleSchemaNode\x12\x11\n\tavro_name\x18\x05 \x01(\t\"R\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x41RCHIVED\x10\x03\x12\r\n\tIN_REVIEW\x10\x04\"\xe3\x01\n\x10SimpleSchemaNode\x12?\n\x04type\x18\x01 \x01(\x0e\x32\x31.strmprivacy.api.entities.v1.SimpleSchemaNodeType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tavro_name\x18\x07 \x01(\t\x12\x10\n\x08repeated\x18\x03 \x01(\x08\x12\x10\n\x08required\x18\x04 \x01(\x08\x12<\n\x05nodes\x18\x05 \x03(\x0b\x32-.strmprivacy.api.entities.v1.SimpleSchemaNode\x12\x0b\n\x03\x64oc\x18\x06 \x01(\t\"\xf3\x01\n\x0eSchemaMetadata\x12\x12\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x34\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x15\n\x08icon_uri\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x06 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\x07 \x03(\tB\x03\xe0\x41\x01\"P\n\x10\x45ventContractRef\x12\x13\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\xe7\x04\n\rEventContract\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12\x44\n\x05state\x18\x02 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.EventContract.StateB\x03\xe0\x41\x03\x12?\n\nschema_ref\x18\x03 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12\x11\n\tis_public\x18\x04 \x01(\x08\x12\x16\n\tkey_field\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12M\n\npii_fields\x18\x06 \x03(\x0b\x32\x39.strmprivacy.api.entities.v1.EventContract.PiiFieldsEntry\x12<\n\x0bvalidations\x18\x07 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.Validation\x12\x44\n\x08metadata\x18\x08 \x01(\x0b\x32\x32.strmprivacy.api.entities.v1.EventContractMetadata\x12\n\n\x02id\x18\t \x01(\t\x1a\x30\n\x0ePiiFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"R\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x41RCHIVED\x10\x03\x12\r\n\tIN_REVIEW\x10\x04\"\xfa\x01\n\x15\x45ventContractMetadata\x12\x12\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x34\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x15\n\x08icon_uri\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x06 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\x07 \x03(\tB\x03\xe0\x41\x01\"-\n\x05Label\x12\x10\n\x03key\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05value\x18\x02 \x01(\tB\x03\xe0\x41\x01\"G\n\nValidation\x12\x12\n\x05\x66ield\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04type\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05value\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\xc2\x02\n\nStreamTree\x12\x38\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamB\x03\xe0\x41\x02\x12:\n\nkey_stream\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KeyStream\x12\x34\n\x07\x64\x65rived\x18\x03 \x03(\x0b\x32#.strmprivacy.api.entities.v1.Stream\x12\x43\n\x0f\x62\x61tch_exporters\x18\x04 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\x12\x43\n\x0fkafka_exporters\x18\x05 \x03(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporter\"\x89\x01\n\x08SinkTree\x12\x34\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkB\x03\xe0\x41\x02\x12\x43\n\x0f\x62\x61tch_exporters\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter:\x02\x18\x01\"\x90\x05\n\x08\x42\x61tchJob\x12:\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02\x12?\n\x06states\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x03\xe0\x41\x03\x12K\n\x0bsource_data\x18\x03 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02\x12@\n\x07\x63onsent\x18\x04 \x01(\x0b\x32*.strmprivacy.api.entities.v1.ConsentConfigB\x03\xe0\x41\x02\x12\x46\n\nencryption\x18\x05 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EncryptionConfigB\x03\xe0\x41\x02\x12N\n\x12\x65vent_contract_ref\x18\x06 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12G\n\x0e\x65ncrypted_data\x18\x07 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EncryptedDataB\x03\xe0\x41\x02\x12R\n\x14\x65ncryption_keys_data\x18\x08 \x01(\x0b\x32/.strmprivacy.api.entities.v1.EncryptionKeysDataB\x03\xe0\x41\x02\x12\x43\n\x0c\x64\x65rived_data\x18\t \x03(\x0b\x32(.strmprivacy.api.entities.v1.DerivedDataB\x03\xe0\x41\x01\"L\n\x10\x45xtendedBatchJob\x12\x38\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJob\"O\n\x0b\x42\x61tchJobRef\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\x9e\x01\n\rBatchJobState\x12\x33\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x42\n\x05state\x18\x02 \x01(\x0e\x32..strmprivacy.api.entities.v1.BatchJobStateTypeB\x03\xe0\x41\x02\x12\x14\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x01\"\xd7\x01\n\x14\x44\x61taConnectorAndType\x12N\n\x12\x64\x61ta_connector_ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x03\xe0\x41\x02\x12\x18\n\x0bpath_prefix\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x16\n\tfile_name\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12=\n\tdata_type\x18\x04 \x01(\x0b\x32%.strmprivacy.api.entities.v1.DataTypeB\x03\xe0\x41\x02\"\x8e\x01\n\rConsentConfig\x12#\n\x16\x64\x65\x66\x61ult_consent_levels\x18\x01 \x03(\x05\x42\x03\xe0\x41\x01\x12X\n\x17\x63onsent_level_extractor\x18\x02 \x01(\x0b\x32\x32.strmprivacy.api.entities.v1.ConsentLevelExtractorB\x03\xe0\x41\x01\"\xe7\x01\n\x15\x43onsentLevelExtractor\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12]\n\x0e\x66ield_patterns\x18\x02 \x03(\x0b\x32\x45.strmprivacy.api.entities.v1.ConsentLevelExtractor.FieldPatternsEntry\x1a`\n\x12\x46ieldPatternsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.ConsentLevels:\x02\x38\x01\"\x80\x01\n\x10\x45ncryptionConfig\x12K\n\x10timestamp_config\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.TimestampConfigB\x03\xe0\x41\x02\x12\x1f\n\x12\x62\x61tch_job_group_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"q\n\x0fTimestampConfig\x12\x12\n\x05\x66ield\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x06\x66ormat\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x35\n\x11\x64\x65\x66\x61ult_time_zone\x18\x03 \x01(\x0b\x32\x15.google.type.TimeZoneB\x03\xe0\x41\x01\"W\n\rEncryptedData\x12\x46\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02\"\\\n\x12\x45ncryptionKeysData\x12\x46\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02\"\xfa\x01\n\x0b\x44\x65rivedData\x12\x46\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02\x12\x16\n\x0e\x63onsent_levels\x18\x02 \x03(\x05\x12I\n\x12\x63onsent_level_type\x18\x03 \x01(\x0e\x32-.strmprivacy.api.entities.v1.ConsentLevelType\x12@\n\rmasked_fields\x18\x04 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFields\"O\n\x0f\x44\x61taContractRef\x12\x13\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\xd7\x06\n\x0c\x44\x61taContract\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12>\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x03\xe0\x41\x02\x12\x43\n\x05state\x18\x03 \x01(\x0e\x32/.strmprivacy.api.entities.v1.DataContract.StateB\x03\xe0\x41\x03\x12\x11\n\tis_public\x18\x04 \x01(\x08\x12!\n\x14\x65vent_sequence_field\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12L\n\npii_fields\x18\x06 \x03(\x0b\x32\x38.strmprivacy.api.entities.v1.DataContract.PiiFieldsEntry\x12<\n\x0bvalidations\x18\x07 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.Validation\x12\x43\n\x08metadata\x18\x08 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataContractMetadata\x12\x17\n\ndefinition\x18\t \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x66ingerprint\x18\n \x01(\tB\x03\xe0\x41\x03\x12W\n\rsimple_schema\x18\x0b \x01(\x0b\x32@.strmprivacy.api.entities.v1.DataContract.SimpleSchemaDefinition\x1a\x30\n\x0ePiiFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x97\x01\n\x16SimpleSchemaDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12<\n\x05nodes\x18\x04 \x03(\x0b\x32-.strmprivacy.api.entities.v1.SimpleSchemaNode\x12\x11\n\tavro_name\x18\x05 \x01(\t\"R\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\r\n\tIN_REVIEW\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08\x41RCHIVED\x10\x04\"\xe2\x01\n\x14\x44\x61taContractMetadata\x12\x12\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x34\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x37\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x06 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\x07 \x03(\tB\x03\xe0\x41\x01\"8\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t*\x8d\x01\n\x11\x42\x61tchJobStateType\x12$\n BATCH_JOB_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x12\n\x0e\x45RROR_STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08\x46INISHED\x10\x05\x12\t\n\x05\x45RROR\x10\x06*T\n\x10\x43onsentLevelType\x12\"\n\x1e\x43ONSENT_LEVEL_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCUMULATIVE\x10\x01\x12\x0c\n\x08GRANULAR\x10\x02*=\n\x08SinkType\x12\x19\n\x15SINK_TYPE_UNSPECIFIED\x10\x00\x12\x06\n\x02S3\x10\x01\x12\n\n\x06GCLOUD\x10\x02\x1a\x02\x18\x01*M\n\rAuthMechanism\x12\x1e\n\x1a\x41UTH_MECHANISM_UNSPECIFIED\x10\x00\x12\x0e\n\nSASL_PLAIN\x10\x01\x12\x0c\n\x08SASL_SSL\x10\x02*C\n\nSchemaType\x12\x1b\n\x17SCHEMA_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x41VRO\x10\x01\x12\x0e\n\nJSONSCHEMA\x10\x02*\x84\x01\n\x14SimpleSchemaNodeType\x12\'\n#SIMPLE_SCHEMA_NODE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\t\n\x05\x46LOAT\x10\x03\x12\x0b\n\x07INTEGER\x10\x04\x12\x08\n\x04LONG\x10\x05\x12\x08\n\x04NODE\x10\n*_\n\x13\x46ilterPublicPrivate\x12%\n!FILTER_PUBLIC_PRIVATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bONLY_PUBLIC\x10\x01\x12\x10\n\x0cONLY_PRIVATE\x10\x02\x42i\n\x1eio.strmprivacy.api.entities.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/entities/v1;entitiesb\x06proto3')

_BATCHJOBSTATETYPE = DESCRIPTOR.enum_types_by_name['BatchJobStateType']
BatchJobStateType = enum_type_wrapper.EnumTypeWrapper(_BATCHJOBSTATETYPE)
_CONSENTLEVELTYPE = DESCRIPTOR.enum_types_by_name['ConsentLevelType']
ConsentLevelType = enum_type_wrapper.EnumTypeWrapper(_CONSENTLEVELTYPE)
_SINKTYPE = DESCRIPTOR.enum_types_by_name['SinkType']
SinkType = enum_type_wrapper.EnumTypeWrapper(_SINKTYPE)
_AUTHMECHANISM = DESCRIPTOR.enum_types_by_name['AuthMechanism']
AuthMechanism = enum_type_wrapper.EnumTypeWrapper(_AUTHMECHANISM)
_SCHEMATYPE = DESCRIPTOR.enum_types_by_name['SchemaType']
SchemaType = enum_type_wrapper.EnumTypeWrapper(_SCHEMATYPE)
_SIMPLESCHEMANODETYPE = DESCRIPTOR.enum_types_by_name['SimpleSchemaNodeType']
SimpleSchemaNodeType = enum_type_wrapper.EnumTypeWrapper(_SIMPLESCHEMANODETYPE)
_FILTERPUBLICPRIVATE = DESCRIPTOR.enum_types_by_name['FilterPublicPrivate']
FilterPublicPrivate = enum_type_wrapper.EnumTypeWrapper(_FILTERPUBLICPRIVATE)
BATCH_JOB_STATE_TYPE_UNSPECIFIED = 0
PENDING = 1
STARTED = 2
ERROR_STARTING = 3
RUNNING = 4
FINISHED = 5
ERROR = 6
CONSENT_LEVEL_TYPE_UNSPECIFIED = 0
CUMULATIVE = 1
GRANULAR = 2
SINK_TYPE_UNSPECIFIED = 0
S3 = 1
GCLOUD = 2
AUTH_MECHANISM_UNSPECIFIED = 0
SASL_PLAIN = 1
SASL_SSL = 2
SCHEMA_TYPE_UNSPECIFIED = 0
AVRO = 1
JSONSCHEMA = 2
SIMPLE_SCHEMA_NODE_TYPE_UNSPECIFIED = 0
STRING = 1
BOOLEAN = 2
FLOAT = 3
INTEGER = 4
LONG = 5
NODE = 10
FILTER_PUBLIC_PRIVATE_UNSPECIFIED = 0
ONLY_PUBLIC = 1
ONLY_PRIVATE = 2


_STREAM = DESCRIPTOR.message_types_by_name['Stream']
_EXTENDEDSTREAM = DESCRIPTOR.message_types_by_name['ExtendedStream']
_EXTENDEDSTREAMGROUP = DESCRIPTOR.message_types_by_name['ExtendedStreamGroup']
_MASKEDFIELDS = DESCRIPTOR.message_types_by_name['MaskedFields']
_MASKEDFIELDS_FIELDPATTERNSENTRY = _MASKEDFIELDS.nested_types_by_name['FieldPatternsEntry']
_MASKEDFIELDS_PATTERNLIST = _MASKEDFIELDS.nested_types_by_name['PatternList']
_LIMITS = DESCRIPTOR.message_types_by_name['Limits']
_KEYSTREAM = DESCRIPTOR.message_types_by_name['KeyStream']
_STREAMREF = DESCRIPTOR.message_types_by_name['StreamRef']
_KEYSTREAMREF = DESCRIPTOR.message_types_by_name['KeyStreamRef']
_CREDENTIALS = DESCRIPTOR.message_types_by_name['Credentials']
_SINK = DESCRIPTOR.message_types_by_name['Sink']
_SINKREF = DESCRIPTOR.message_types_by_name['SinkRef']
_BUCKETCONFIG = DESCRIPTOR.message_types_by_name['BucketConfig']
_DATACONNECTOR = DESCRIPTOR.message_types_by_name['DataConnector']
_DATACONNECTORREF = DESCRIPTOR.message_types_by_name['DataConnectorRef']
_DATACONNECTORDEPENDENTENTITIES = DESCRIPTOR.message_types_by_name['DataConnectorDependentEntities']
_AWSS3BUCKETLOCATION = DESCRIPTOR.message_types_by_name['AwsS3BucketLocation']
_GOOGLECLOUDSTORAGEBUCKETLOCATION = DESCRIPTOR.message_types_by_name['GoogleCloudStorageBucketLocation']
_AZUREBLOBSTORAGECONTAINERLOCATION = DESCRIPTOR.message_types_by_name['AzureBlobStorageContainerLocation']
_AZURECLIENTSECRETCREDENTIAL = DESCRIPTOR.message_types_by_name['AzureClientSecretCredential']
_DATATYPE = DESCRIPTOR.message_types_by_name['DataType']
_CSVCONFIG = DESCRIPTOR.message_types_by_name['CsvConfig']
_BATCHEXPORTER = DESCRIPTOR.message_types_by_name['BatchExporter']
_EXTENDEDBATCHEXPORTER = DESCRIPTOR.message_types_by_name['ExtendedBatchExporter']
_BATCHEXPORTERREF = DESCRIPTOR.message_types_by_name['BatchExporterRef']
_KAFKACLUSTER = DESCRIPTOR.message_types_by_name['KafkaCluster']
_KAFKACLUSTERREF = DESCRIPTOR.message_types_by_name['KafkaClusterRef']
_KAFKAEXPORTER = DESCRIPTOR.message_types_by_name['KafkaExporter']
_KAFKAEXPORTERREF = DESCRIPTOR.message_types_by_name['KafkaExporterRef']
_KAFKAEXPORTERTARGET = DESCRIPTOR.message_types_by_name['KafkaExporterTarget']
_KAFKAUSER = DESCRIPTOR.message_types_by_name['KafkaUser']
_KAFKAUSERREF = DESCRIPTOR.message_types_by_name['KafkaUserRef']
_CONSENTLEVELS = DESCRIPTOR.message_types_by_name['ConsentLevels']
_CONSENTLEVELMAPPING = DESCRIPTOR.message_types_by_name['ConsentLevelMapping']
_CONSENTLEVELMAPPINGREF = DESCRIPTOR.message_types_by_name['ConsentLevelMappingRef']
_WINDOWEDEVENTCOUNT = DESCRIPTOR.message_types_by_name['WindowedEventCount']
_SCHEMAREF = DESCRIPTOR.message_types_by_name['SchemaRef']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_SCHEMA_SIMPLESCHEMADEFINITION = _SCHEMA.nested_types_by_name['SimpleSchemaDefinition']
_SIMPLESCHEMANODE = DESCRIPTOR.message_types_by_name['SimpleSchemaNode']
_SCHEMAMETADATA = DESCRIPTOR.message_types_by_name['SchemaMetadata']
_EVENTCONTRACTREF = DESCRIPTOR.message_types_by_name['EventContractRef']
_EVENTCONTRACT = DESCRIPTOR.message_types_by_name['EventContract']
_EVENTCONTRACT_PIIFIELDSENTRY = _EVENTCONTRACT.nested_types_by_name['PiiFieldsEntry']
_EVENTCONTRACTMETADATA = DESCRIPTOR.message_types_by_name['EventContractMetadata']
_LABEL = DESCRIPTOR.message_types_by_name['Label']
_VALIDATION = DESCRIPTOR.message_types_by_name['Validation']
_STREAMTREE = DESCRIPTOR.message_types_by_name['StreamTree']
_SINKTREE = DESCRIPTOR.message_types_by_name['SinkTree']
_BATCHJOB = DESCRIPTOR.message_types_by_name['BatchJob']
_EXTENDEDBATCHJOB = DESCRIPTOR.message_types_by_name['ExtendedBatchJob']
_BATCHJOBREF = DESCRIPTOR.message_types_by_name['BatchJobRef']
_BATCHJOBSTATE = DESCRIPTOR.message_types_by_name['BatchJobState']
_DATACONNECTORANDTYPE = DESCRIPTOR.message_types_by_name['DataConnectorAndType']
_CONSENTCONFIG = DESCRIPTOR.message_types_by_name['ConsentConfig']
_CONSENTLEVELEXTRACTOR = DESCRIPTOR.message_types_by_name['ConsentLevelExtractor']
_CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY = _CONSENTLEVELEXTRACTOR.nested_types_by_name['FieldPatternsEntry']
_ENCRYPTIONCONFIG = DESCRIPTOR.message_types_by_name['EncryptionConfig']
_TIMESTAMPCONFIG = DESCRIPTOR.message_types_by_name['TimestampConfig']
_ENCRYPTEDDATA = DESCRIPTOR.message_types_by_name['EncryptedData']
_ENCRYPTIONKEYSDATA = DESCRIPTOR.message_types_by_name['EncryptionKeysData']
_DERIVEDDATA = DESCRIPTOR.message_types_by_name['DerivedData']
_DATACONTRACTREF = DESCRIPTOR.message_types_by_name['DataContractRef']
_DATACONTRACT = DESCRIPTOR.message_types_by_name['DataContract']
_DATACONTRACT_PIIFIELDSENTRY = _DATACONTRACT.nested_types_by_name['PiiFieldsEntry']
_DATACONTRACT_SIMPLESCHEMADEFINITION = _DATACONTRACT.nested_types_by_name['SimpleSchemaDefinition']
_DATACONTRACTMETADATA = DESCRIPTOR.message_types_by_name['DataContractMetadata']
_PROJECT = DESCRIPTOR.message_types_by_name['Project']
_SCHEMA_STATE = _SCHEMA.enum_types_by_name['State']
_EVENTCONTRACT_STATE = _EVENTCONTRACT.enum_types_by_name['State']
_DATACONTRACT_STATE = _DATACONTRACT.enum_types_by_name['State']
Stream = _reflection.GeneratedProtocolMessageType('Stream', (_message.Message,), {
  'DESCRIPTOR' : _STREAM,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Stream)
  })
_sym_db.RegisterMessage(Stream)

ExtendedStream = _reflection.GeneratedProtocolMessageType('ExtendedStream', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDEDSTREAM,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ExtendedStream)
  })
_sym_db.RegisterMessage(ExtendedStream)

ExtendedStreamGroup = _reflection.GeneratedProtocolMessageType('ExtendedStreamGroup', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDEDSTREAMGROUP,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ExtendedStreamGroup)
  })
_sym_db.RegisterMessage(ExtendedStreamGroup)

MaskedFields = _reflection.GeneratedProtocolMessageType('MaskedFields', (_message.Message,), {

  'FieldPatternsEntry' : _reflection.GeneratedProtocolMessageType('FieldPatternsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MASKEDFIELDS_FIELDPATTERNSENTRY,
    '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.MaskedFields.FieldPatternsEntry)
    })
  ,

  'PatternList' : _reflection.GeneratedProtocolMessageType('PatternList', (_message.Message,), {
    'DESCRIPTOR' : _MASKEDFIELDS_PATTERNLIST,
    '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.MaskedFields.PatternList)
    })
  ,
  'DESCRIPTOR' : _MASKEDFIELDS,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.MaskedFields)
  })
_sym_db.RegisterMessage(MaskedFields)
_sym_db.RegisterMessage(MaskedFields.FieldPatternsEntry)
_sym_db.RegisterMessage(MaskedFields.PatternList)

Limits = _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
  'DESCRIPTOR' : _LIMITS,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Limits)
  })
_sym_db.RegisterMessage(Limits)

KeyStream = _reflection.GeneratedProtocolMessageType('KeyStream', (_message.Message,), {
  'DESCRIPTOR' : _KEYSTREAM,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KeyStream)
  })
_sym_db.RegisterMessage(KeyStream)

StreamRef = _reflection.GeneratedProtocolMessageType('StreamRef', (_message.Message,), {
  'DESCRIPTOR' : _STREAMREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.StreamRef)
  })
_sym_db.RegisterMessage(StreamRef)

KeyStreamRef = _reflection.GeneratedProtocolMessageType('KeyStreamRef', (_message.Message,), {
  'DESCRIPTOR' : _KEYSTREAMREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KeyStreamRef)
  })
_sym_db.RegisterMessage(KeyStreamRef)

Credentials = _reflection.GeneratedProtocolMessageType('Credentials', (_message.Message,), {
  'DESCRIPTOR' : _CREDENTIALS,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Credentials)
  })
_sym_db.RegisterMessage(Credentials)

Sink = _reflection.GeneratedProtocolMessageType('Sink', (_message.Message,), {
  'DESCRIPTOR' : _SINK,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Sink)
  })
_sym_db.RegisterMessage(Sink)

SinkRef = _reflection.GeneratedProtocolMessageType('SinkRef', (_message.Message,), {
  'DESCRIPTOR' : _SINKREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.SinkRef)
  })
_sym_db.RegisterMessage(SinkRef)

BucketConfig = _reflection.GeneratedProtocolMessageType('BucketConfig', (_message.Message,), {
  'DESCRIPTOR' : _BUCKETCONFIG,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.BucketConfig)
  })
_sym_db.RegisterMessage(BucketConfig)

DataConnector = _reflection.GeneratedProtocolMessageType('DataConnector', (_message.Message,), {
  'DESCRIPTOR' : _DATACONNECTOR,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataConnector)
  })
_sym_db.RegisterMessage(DataConnector)

DataConnectorRef = _reflection.GeneratedProtocolMessageType('DataConnectorRef', (_message.Message,), {
  'DESCRIPTOR' : _DATACONNECTORREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataConnectorRef)
  })
_sym_db.RegisterMessage(DataConnectorRef)

DataConnectorDependentEntities = _reflection.GeneratedProtocolMessageType('DataConnectorDependentEntities', (_message.Message,), {
  'DESCRIPTOR' : _DATACONNECTORDEPENDENTENTITIES,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataConnectorDependentEntities)
  })
_sym_db.RegisterMessage(DataConnectorDependentEntities)

AwsS3BucketLocation = _reflection.GeneratedProtocolMessageType('AwsS3BucketLocation', (_message.Message,), {
  'DESCRIPTOR' : _AWSS3BUCKETLOCATION,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.AwsS3BucketLocation)
  })
_sym_db.RegisterMessage(AwsS3BucketLocation)

GoogleCloudStorageBucketLocation = _reflection.GeneratedProtocolMessageType('GoogleCloudStorageBucketLocation', (_message.Message,), {
  'DESCRIPTOR' : _GOOGLECLOUDSTORAGEBUCKETLOCATION,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.GoogleCloudStorageBucketLocation)
  })
_sym_db.RegisterMessage(GoogleCloudStorageBucketLocation)

AzureBlobStorageContainerLocation = _reflection.GeneratedProtocolMessageType('AzureBlobStorageContainerLocation', (_message.Message,), {
  'DESCRIPTOR' : _AZUREBLOBSTORAGECONTAINERLOCATION,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.AzureBlobStorageContainerLocation)
  })
_sym_db.RegisterMessage(AzureBlobStorageContainerLocation)

AzureClientSecretCredential = _reflection.GeneratedProtocolMessageType('AzureClientSecretCredential', (_message.Message,), {
  'DESCRIPTOR' : _AZURECLIENTSECRETCREDENTIAL,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.AzureClientSecretCredential)
  })
_sym_db.RegisterMessage(AzureClientSecretCredential)

DataType = _reflection.GeneratedProtocolMessageType('DataType', (_message.Message,), {
  'DESCRIPTOR' : _DATATYPE,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataType)
  })
_sym_db.RegisterMessage(DataType)

CsvConfig = _reflection.GeneratedProtocolMessageType('CsvConfig', (_message.Message,), {
  'DESCRIPTOR' : _CSVCONFIG,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.CsvConfig)
  })
_sym_db.RegisterMessage(CsvConfig)

BatchExporter = _reflection.GeneratedProtocolMessageType('BatchExporter', (_message.Message,), {
  'DESCRIPTOR' : _BATCHEXPORTER,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.BatchExporter)
  })
_sym_db.RegisterMessage(BatchExporter)

ExtendedBatchExporter = _reflection.GeneratedProtocolMessageType('ExtendedBatchExporter', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDEDBATCHEXPORTER,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ExtendedBatchExporter)
  })
_sym_db.RegisterMessage(ExtendedBatchExporter)

BatchExporterRef = _reflection.GeneratedProtocolMessageType('BatchExporterRef', (_message.Message,), {
  'DESCRIPTOR' : _BATCHEXPORTERREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.BatchExporterRef)
  })
_sym_db.RegisterMessage(BatchExporterRef)

KafkaCluster = _reflection.GeneratedProtocolMessageType('KafkaCluster', (_message.Message,), {
  'DESCRIPTOR' : _KAFKACLUSTER,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KafkaCluster)
  })
_sym_db.RegisterMessage(KafkaCluster)

KafkaClusterRef = _reflection.GeneratedProtocolMessageType('KafkaClusterRef', (_message.Message,), {
  'DESCRIPTOR' : _KAFKACLUSTERREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KafkaClusterRef)
  })
_sym_db.RegisterMessage(KafkaClusterRef)

KafkaExporter = _reflection.GeneratedProtocolMessageType('KafkaExporter', (_message.Message,), {
  'DESCRIPTOR' : _KAFKAEXPORTER,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KafkaExporter)
  })
_sym_db.RegisterMessage(KafkaExporter)

KafkaExporterRef = _reflection.GeneratedProtocolMessageType('KafkaExporterRef', (_message.Message,), {
  'DESCRIPTOR' : _KAFKAEXPORTERREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KafkaExporterRef)
  })
_sym_db.RegisterMessage(KafkaExporterRef)

KafkaExporterTarget = _reflection.GeneratedProtocolMessageType('KafkaExporterTarget', (_message.Message,), {
  'DESCRIPTOR' : _KAFKAEXPORTERTARGET,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KafkaExporterTarget)
  })
_sym_db.RegisterMessage(KafkaExporterTarget)

KafkaUser = _reflection.GeneratedProtocolMessageType('KafkaUser', (_message.Message,), {
  'DESCRIPTOR' : _KAFKAUSER,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KafkaUser)
  })
_sym_db.RegisterMessage(KafkaUser)

KafkaUserRef = _reflection.GeneratedProtocolMessageType('KafkaUserRef', (_message.Message,), {
  'DESCRIPTOR' : _KAFKAUSERREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.KafkaUserRef)
  })
_sym_db.RegisterMessage(KafkaUserRef)

ConsentLevels = _reflection.GeneratedProtocolMessageType('ConsentLevels', (_message.Message,), {
  'DESCRIPTOR' : _CONSENTLEVELS,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ConsentLevels)
  })
_sym_db.RegisterMessage(ConsentLevels)

ConsentLevelMapping = _reflection.GeneratedProtocolMessageType('ConsentLevelMapping', (_message.Message,), {
  'DESCRIPTOR' : _CONSENTLEVELMAPPING,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ConsentLevelMapping)
  })
_sym_db.RegisterMessage(ConsentLevelMapping)

ConsentLevelMappingRef = _reflection.GeneratedProtocolMessageType('ConsentLevelMappingRef', (_message.Message,), {
  'DESCRIPTOR' : _CONSENTLEVELMAPPINGREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ConsentLevelMappingRef)
  })
_sym_db.RegisterMessage(ConsentLevelMappingRef)

WindowedEventCount = _reflection.GeneratedProtocolMessageType('WindowedEventCount', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWEDEVENTCOUNT,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.WindowedEventCount)
  })
_sym_db.RegisterMessage(WindowedEventCount)

SchemaRef = _reflection.GeneratedProtocolMessageType('SchemaRef', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.SchemaRef)
  })
_sym_db.RegisterMessage(SchemaRef)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {

  'SimpleSchemaDefinition' : _reflection.GeneratedProtocolMessageType('SimpleSchemaDefinition', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMA_SIMPLESCHEMADEFINITION,
    '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinition)
    })
  ,
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Schema)
  })
_sym_db.RegisterMessage(Schema)
_sym_db.RegisterMessage(Schema.SimpleSchemaDefinition)

SimpleSchemaNode = _reflection.GeneratedProtocolMessageType('SimpleSchemaNode', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLESCHEMANODE,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.SimpleSchemaNode)
  })
_sym_db.RegisterMessage(SimpleSchemaNode)

SchemaMetadata = _reflection.GeneratedProtocolMessageType('SchemaMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAMETADATA,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.SchemaMetadata)
  })
_sym_db.RegisterMessage(SchemaMetadata)

EventContractRef = _reflection.GeneratedProtocolMessageType('EventContractRef', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCONTRACTREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.EventContractRef)
  })
_sym_db.RegisterMessage(EventContractRef)

EventContract = _reflection.GeneratedProtocolMessageType('EventContract', (_message.Message,), {

  'PiiFieldsEntry' : _reflection.GeneratedProtocolMessageType('PiiFieldsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EVENTCONTRACT_PIIFIELDSENTRY,
    '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.EventContract.PiiFieldsEntry)
    })
  ,
  'DESCRIPTOR' : _EVENTCONTRACT,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.EventContract)
  })
_sym_db.RegisterMessage(EventContract)
_sym_db.RegisterMessage(EventContract.PiiFieldsEntry)

EventContractMetadata = _reflection.GeneratedProtocolMessageType('EventContractMetadata', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCONTRACTMETADATA,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.EventContractMetadata)
  })
_sym_db.RegisterMessage(EventContractMetadata)

Label = _reflection.GeneratedProtocolMessageType('Label', (_message.Message,), {
  'DESCRIPTOR' : _LABEL,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Label)
  })
_sym_db.RegisterMessage(Label)

Validation = _reflection.GeneratedProtocolMessageType('Validation', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATION,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Validation)
  })
_sym_db.RegisterMessage(Validation)

StreamTree = _reflection.GeneratedProtocolMessageType('StreamTree', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTREE,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.StreamTree)
  })
_sym_db.RegisterMessage(StreamTree)

SinkTree = _reflection.GeneratedProtocolMessageType('SinkTree', (_message.Message,), {
  'DESCRIPTOR' : _SINKTREE,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.SinkTree)
  })
_sym_db.RegisterMessage(SinkTree)

BatchJob = _reflection.GeneratedProtocolMessageType('BatchJob', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOB,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.BatchJob)
  })
_sym_db.RegisterMessage(BatchJob)

ExtendedBatchJob = _reflection.GeneratedProtocolMessageType('ExtendedBatchJob', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDEDBATCHJOB,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ExtendedBatchJob)
  })
_sym_db.RegisterMessage(ExtendedBatchJob)

BatchJobRef = _reflection.GeneratedProtocolMessageType('BatchJobRef', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.BatchJobRef)
  })
_sym_db.RegisterMessage(BatchJobRef)

BatchJobState = _reflection.GeneratedProtocolMessageType('BatchJobState', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBSTATE,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.BatchJobState)
  })
_sym_db.RegisterMessage(BatchJobState)

DataConnectorAndType = _reflection.GeneratedProtocolMessageType('DataConnectorAndType', (_message.Message,), {
  'DESCRIPTOR' : _DATACONNECTORANDTYPE,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataConnectorAndType)
  })
_sym_db.RegisterMessage(DataConnectorAndType)

ConsentConfig = _reflection.GeneratedProtocolMessageType('ConsentConfig', (_message.Message,), {
  'DESCRIPTOR' : _CONSENTCONFIG,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ConsentConfig)
  })
_sym_db.RegisterMessage(ConsentConfig)

ConsentLevelExtractor = _reflection.GeneratedProtocolMessageType('ConsentLevelExtractor', (_message.Message,), {

  'FieldPatternsEntry' : _reflection.GeneratedProtocolMessageType('FieldPatternsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY,
    '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ConsentLevelExtractor.FieldPatternsEntry)
    })
  ,
  'DESCRIPTOR' : _CONSENTLEVELEXTRACTOR,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.ConsentLevelExtractor)
  })
_sym_db.RegisterMessage(ConsentLevelExtractor)
_sym_db.RegisterMessage(ConsentLevelExtractor.FieldPatternsEntry)

EncryptionConfig = _reflection.GeneratedProtocolMessageType('EncryptionConfig', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTIONCONFIG,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.EncryptionConfig)
  })
_sym_db.RegisterMessage(EncryptionConfig)

TimestampConfig = _reflection.GeneratedProtocolMessageType('TimestampConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPCONFIG,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.TimestampConfig)
  })
_sym_db.RegisterMessage(TimestampConfig)

EncryptedData = _reflection.GeneratedProtocolMessageType('EncryptedData', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDDATA,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.EncryptedData)
  })
_sym_db.RegisterMessage(EncryptedData)

EncryptionKeysData = _reflection.GeneratedProtocolMessageType('EncryptionKeysData', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTIONKEYSDATA,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.EncryptionKeysData)
  })
_sym_db.RegisterMessage(EncryptionKeysData)

DerivedData = _reflection.GeneratedProtocolMessageType('DerivedData', (_message.Message,), {
  'DESCRIPTOR' : _DERIVEDDATA,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DerivedData)
  })
_sym_db.RegisterMessage(DerivedData)

DataContractRef = _reflection.GeneratedProtocolMessageType('DataContractRef', (_message.Message,), {
  'DESCRIPTOR' : _DATACONTRACTREF,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataContractRef)
  })
_sym_db.RegisterMessage(DataContractRef)

DataContract = _reflection.GeneratedProtocolMessageType('DataContract', (_message.Message,), {

  'PiiFieldsEntry' : _reflection.GeneratedProtocolMessageType('PiiFieldsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATACONTRACT_PIIFIELDSENTRY,
    '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataContract.PiiFieldsEntry)
    })
  ,

  'SimpleSchemaDefinition' : _reflection.GeneratedProtocolMessageType('SimpleSchemaDefinition', (_message.Message,), {
    'DESCRIPTOR' : _DATACONTRACT_SIMPLESCHEMADEFINITION,
    '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataContract.SimpleSchemaDefinition)
    })
  ,
  'DESCRIPTOR' : _DATACONTRACT,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataContract)
  })
_sym_db.RegisterMessage(DataContract)
_sym_db.RegisterMessage(DataContract.PiiFieldsEntry)
_sym_db.RegisterMessage(DataContract.SimpleSchemaDefinition)

DataContractMetadata = _reflection.GeneratedProtocolMessageType('DataContractMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DATACONTRACTMETADATA,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.DataContractMetadata)
  })
_sym_db.RegisterMessage(DataContractMetadata)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
  'DESCRIPTOR' : _PROJECT,
  '__module__' : 'strmprivacy.api.entities.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.entities.v1.Project)
  })
_sym_db.RegisterMessage(Project)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.entities.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/entities/v1;entities'
  _SINKTYPE._options = None
  _SINKTYPE._serialized_options = b'\030\001'
  _STREAM.fields_by_name['ref']._options = None
  _STREAM.fields_by_name['ref']._serialized_options = b'\340A\002'
  _STREAM.fields_by_name['enabled']._options = None
  _STREAM.fields_by_name['enabled']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['limits']._options = None
  _STREAM.fields_by_name['limits']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['credentials']._options = None
  _STREAM.fields_by_name['credentials']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['kafka_topic']._options = None
  _STREAM.fields_by_name['kafka_topic']._serialized_options = b'\340A\003'
  _MASKEDFIELDS_FIELDPATTERNSENTRY._options = None
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_options = b'8\001'
  _LIMITS.fields_by_name['event_rate']._options = None
  _LIMITS.fields_by_name['event_rate']._serialized_options = b'\340A\003'
  _LIMITS.fields_by_name['event_count']._options = None
  _LIMITS.fields_by_name['event_count']._serialized_options = b'\340A\003'
  _KEYSTREAM.fields_by_name['ref']._options = None
  _KEYSTREAM.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KEYSTREAM.fields_by_name['status']._options = None
  _KEYSTREAM.fields_by_name['status']._serialized_options = b'\340A\003'
  _KEYSTREAM.fields_by_name['kafka_topic']._options = None
  _KEYSTREAM.fields_by_name['kafka_topic']._serialized_options = b'\340A\003'
  _STREAMREF.fields_by_name['billing_id']._options = None
  _STREAMREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _STREAMREF.fields_by_name['name']._options = None
  _STREAMREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _STREAMREF.fields_by_name['project_id']._options = None
  _STREAMREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _KEYSTREAMREF.fields_by_name['billing_id']._options = None
  _KEYSTREAMREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KEYSTREAMREF.fields_by_name['name']._options = None
  _KEYSTREAMREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _KEYSTREAMREF.fields_by_name['project_id']._options = None
  _KEYSTREAMREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['billing_id']._options = None
  _CREDENTIALS.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREDENTIALS.fields_by_name['client_id']._options = None
  _CREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['client_secret']._options = None
  _CREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['project_id']._options = None
  _CREDENTIALS.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _SINK.fields_by_name['ref']._options = None
  _SINK.fields_by_name['ref']._serialized_options = b'\340A\002'
  _SINK.fields_by_name['sink_type']._options = None
  _SINK.fields_by_name['sink_type']._serialized_options = b'\340A\002'
  _SINK._options = None
  _SINK._serialized_options = b'\030\001'
  _SINKREF.fields_by_name['billing_id']._options = None
  _SINKREF.fields_by_name['billing_id']._serialized_options = b'\340A\002'
  _SINKREF.fields_by_name['name']._options = None
  _SINKREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _SINKREF._options = None
  _SINKREF._serialized_options = b'\030\001'
  _BUCKETCONFIG.fields_by_name['bucket_name']._options = None
  _BUCKETCONFIG.fields_by_name['bucket_name']._serialized_options = b'\340A\002'
  _BUCKETCONFIG.fields_by_name['credentials']._options = None
  _BUCKETCONFIG.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _DATACONNECTORREF.fields_by_name['billing_id']._options = None
  _DATACONNECTORREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _AWSS3BUCKETLOCATION.fields_by_name['bucket_name']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['bucket_name']._serialized_options = b'\340A\002'
  _AWSS3BUCKETLOCATION.fields_by_name['credentials']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _AWSS3BUCKETLOCATION.fields_by_name['assume_role_arn']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['assume_role_arn']._serialized_options = b'\340A\001'
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['bucket_name']._options = None
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['bucket_name']._serialized_options = b'\340A\002'
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['credentials']._options = None
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['storage_account_uri']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['storage_account_uri']._serialized_options = b'\340A\002'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['container_name']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['container_name']._serialized_options = b'\340A\002'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['client_secret_credential']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['client_secret_credential']._serialized_options = b'\340A\002'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['tenant_id']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['tenant_id']._serialized_options = b'\340A\002'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_id']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_id']._serialized_options = b'\340A\002'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_secret']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_secret']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['ref']._options = None
  _BATCHEXPORTER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['stream_ref']._options = None
  _BATCHEXPORTER.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['key_stream_ref']._options = None
  _BATCHEXPORTER.fields_by_name['key_stream_ref']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['interval']._options = None
  _BATCHEXPORTER.fields_by_name['interval']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['sink_name']._options = None
  _BATCHEXPORTER.fields_by_name['sink_name']._serialized_options = b'\340A\002'
  _BATCHEXPORTERREF.fields_by_name['billing_id']._options = None
  _BATCHEXPORTERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _BATCHEXPORTERREF.fields_by_name['name']._options = None
  _BATCHEXPORTERREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _BATCHEXPORTERREF.fields_by_name['project_id']._options = None
  _BATCHEXPORTERREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _KAFKACLUSTER.fields_by_name['ref']._options = None
  _KAFKACLUSTER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KAFKACLUSTER.fields_by_name['bootstrap_servers']._options = None
  _KAFKACLUSTER.fields_by_name['bootstrap_servers']._serialized_options = b'\340A\002'
  _KAFKACLUSTER.fields_by_name['auth_mechanism']._options = None
  _KAFKACLUSTER.fields_by_name['auth_mechanism']._serialized_options = b'\340A\002'
  _KAFKACLUSTERREF.fields_by_name['billing_id']._options = None
  _KAFKACLUSTERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KAFKACLUSTERREF.fields_by_name['name']._options = None
  _KAFKACLUSTERREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _KAFKACLUSTERREF.fields_by_name['project_id']._options = None
  _KAFKACLUSTERREF.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _KAFKAEXPORTER.fields_by_name['ref']._options = None
  _KAFKAEXPORTER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KAFKAEXPORTER.fields_by_name['stream_ref']._options = None
  _KAFKAEXPORTER.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _KAFKAEXPORTER.fields_by_name['target']._options = None
  _KAFKAEXPORTER.fields_by_name['target']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERREF.fields_by_name['billing_id']._options = None
  _KAFKAEXPORTERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KAFKAEXPORTERREF.fields_by_name['name']._options = None
  _KAFKAEXPORTERREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERREF.fields_by_name['project_id']._options = None
  _KAFKAEXPORTERREF.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERTARGET.fields_by_name['cluster_ref']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['cluster_ref']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERTARGET.fields_by_name['topic']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['topic']._serialized_options = b'\340A\002'
  _KAFKAUSER.fields_by_name['ref']._options = None
  _KAFKAUSER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KAFKAUSER.fields_by_name['kafka_exporter_name']._options = None
  _KAFKAUSER.fields_by_name['kafka_exporter_name']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['topic']._options = None
  _KAFKAUSER.fields_by_name['topic']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['client_id']._options = None
  _KAFKAUSER.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['client_secret']._options = None
  _KAFKAUSER.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['cluster_ref']._options = None
  _KAFKAUSER.fields_by_name['cluster_ref']._serialized_options = b'\340A\003'
  _KAFKAUSERREF.fields_by_name['billing_id']._options = None
  _KAFKAUSERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KAFKAUSERREF.fields_by_name['name']._options = None
  _KAFKAUSERREF.fields_by_name['name']._serialized_options = b'\340A\003'
  _KAFKAUSERREF.fields_by_name['project_id']._options = None
  _KAFKAUSERREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _CONSENTLEVELMAPPING.fields_by_name['ref']._options = None
  _CONSENTLEVELMAPPING.fields_by_name['ref']._serialized_options = b'\340A\002'
  _CONSENTLEVELMAPPING.fields_by_name['name']._options = None
  _CONSENTLEVELMAPPING.fields_by_name['name']._serialized_options = b'\340A\002'
  _CONSENTLEVELMAPPINGREF.fields_by_name['billing_id']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CONSENTLEVELMAPPINGREF.fields_by_name['level']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['level']._serialized_options = b'\340A\002'
  _CONSENTLEVELMAPPINGREF.fields_by_name['project_id']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _WINDOWEDEVENTCOUNT.fields_by_name['start_time']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['start_time']._serialized_options = b'\340A\003'
  _WINDOWEDEVENTCOUNT.fields_by_name['end_time']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['end_time']._serialized_options = b'\340A\003'
  _WINDOWEDEVENTCOUNT.fields_by_name['event_count']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['event_count']._serialized_options = b'\340A\003'
  _SCHEMAREF.fields_by_name['handle']._options = None
  _SCHEMAREF.fields_by_name['handle']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['name']._options = None
  _SCHEMAREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['version']._options = None
  _SCHEMAREF.fields_by_name['version']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['schema_type']._options = None
  _SCHEMAREF.fields_by_name['schema_type']._serialized_options = b'\340A\003'
  _SCHEMA.fields_by_name['ref']._options = None
  _SCHEMA.fields_by_name['ref']._serialized_options = b'\340A\002'
  _SCHEMA.fields_by_name['state']._options = None
  _SCHEMA.fields_by_name['state']._serialized_options = b'\340A\003'
  _SCHEMA.fields_by_name['definition']._options = None
  _SCHEMA.fields_by_name['definition']._serialized_options = b'\340A\002'
  _SCHEMA.fields_by_name['fingerprint']._options = None
  _SCHEMA.fields_by_name['fingerprint']._serialized_options = b'\340A\003'
  _SCHEMAMETADATA.fields_by_name['title']._options = None
  _SCHEMAMETADATA.fields_by_name['title']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['description']._options = None
  _SCHEMAMETADATA.fields_by_name['description']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['create_time']._options = None
  _SCHEMAMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _SCHEMAMETADATA.fields_by_name['icon_uri']._options = None
  _SCHEMAMETADATA.fields_by_name['icon_uri']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['labels']._options = None
  _SCHEMAMETADATA.fields_by_name['labels']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['domains']._options = None
  _SCHEMAMETADATA.fields_by_name['domains']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['industries']._options = None
  _SCHEMAMETADATA.fields_by_name['industries']._serialized_options = b'\340A\001'
  _EVENTCONTRACTREF.fields_by_name['handle']._options = None
  _EVENTCONTRACTREF.fields_by_name['handle']._serialized_options = b'\340A\002'
  _EVENTCONTRACTREF.fields_by_name['name']._options = None
  _EVENTCONTRACTREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _EVENTCONTRACTREF.fields_by_name['version']._options = None
  _EVENTCONTRACTREF.fields_by_name['version']._serialized_options = b'\340A\002'
  _EVENTCONTRACT_PIIFIELDSENTRY._options = None
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_options = b'8\001'
  _EVENTCONTRACT.fields_by_name['ref']._options = None
  _EVENTCONTRACT.fields_by_name['ref']._serialized_options = b'\340A\002'
  _EVENTCONTRACT.fields_by_name['state']._options = None
  _EVENTCONTRACT.fields_by_name['state']._serialized_options = b'\340A\003'
  _EVENTCONTRACT.fields_by_name['schema_ref']._options = None
  _EVENTCONTRACT.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _EVENTCONTRACT.fields_by_name['key_field']._options = None
  _EVENTCONTRACT.fields_by_name['key_field']._serialized_options = b'\340A\002'
  _EVENTCONTRACTMETADATA.fields_by_name['title']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['title']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['description']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['description']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['create_time']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _EVENTCONTRACTMETADATA.fields_by_name['icon_uri']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['icon_uri']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['labels']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['labels']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['domains']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['domains']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['industries']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['industries']._serialized_options = b'\340A\001'
  _LABEL.fields_by_name['key']._options = None
  _LABEL.fields_by_name['key']._serialized_options = b'\340A\002'
  _LABEL.fields_by_name['value']._options = None
  _LABEL.fields_by_name['value']._serialized_options = b'\340A\001'
  _VALIDATION.fields_by_name['field']._options = None
  _VALIDATION.fields_by_name['field']._serialized_options = b'\340A\002'
  _VALIDATION.fields_by_name['type']._options = None
  _VALIDATION.fields_by_name['type']._serialized_options = b'\340A\002'
  _VALIDATION.fields_by_name['value']._options = None
  _VALIDATION.fields_by_name['value']._serialized_options = b'\340A\002'
  _STREAMTREE.fields_by_name['stream']._options = None
  _STREAMTREE.fields_by_name['stream']._serialized_options = b'\340A\002'
  _SINKTREE.fields_by_name['sink']._options = None
  _SINKTREE.fields_by_name['sink']._serialized_options = b'\340A\002'
  _SINKTREE._options = None
  _SINKTREE._serialized_options = b'\030\001'
  _BATCHJOB.fields_by_name['ref']._options = None
  _BATCHJOB.fields_by_name['ref']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['states']._options = None
  _BATCHJOB.fields_by_name['states']._serialized_options = b'\340A\003'
  _BATCHJOB.fields_by_name['source_data']._options = None
  _BATCHJOB.fields_by_name['source_data']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['consent']._options = None
  _BATCHJOB.fields_by_name['consent']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['encryption']._options = None
  _BATCHJOB.fields_by_name['encryption']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['event_contract_ref']._options = None
  _BATCHJOB.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['encrypted_data']._options = None
  _BATCHJOB.fields_by_name['encrypted_data']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['encryption_keys_data']._options = None
  _BATCHJOB.fields_by_name['encryption_keys_data']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['derived_data']._options = None
  _BATCHJOB.fields_by_name['derived_data']._serialized_options = b'\340A\001'
  _BATCHJOBREF.fields_by_name['billing_id']._options = None
  _BATCHJOBREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _BATCHJOBREF.fields_by_name['id']._options = None
  _BATCHJOBREF.fields_by_name['id']._serialized_options = b'\340A\003'
  _BATCHJOBREF.fields_by_name['project_id']._options = None
  _BATCHJOBREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _BATCHJOBSTATE.fields_by_name['state_time']._options = None
  _BATCHJOBSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _BATCHJOBSTATE.fields_by_name['state']._options = None
  _BATCHJOBSTATE.fields_by_name['state']._serialized_options = b'\340A\002'
  _BATCHJOBSTATE.fields_by_name['message']._options = None
  _BATCHJOBSTATE.fields_by_name['message']._serialized_options = b'\340A\001'
  _DATACONNECTORANDTYPE.fields_by_name['data_connector_ref']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['data_connector_ref']._serialized_options = b'\340A\002'
  _DATACONNECTORANDTYPE.fields_by_name['path_prefix']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['path_prefix']._serialized_options = b'\340A\001'
  _DATACONNECTORANDTYPE.fields_by_name['file_name']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['file_name']._serialized_options = b'\340A\001'
  _DATACONNECTORANDTYPE.fields_by_name['data_type']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['data_type']._serialized_options = b'\340A\002'
  _CONSENTCONFIG.fields_by_name['default_consent_levels']._options = None
  _CONSENTCONFIG.fields_by_name['default_consent_levels']._serialized_options = b'\340A\001'
  _CONSENTCONFIG.fields_by_name['consent_level_extractor']._options = None
  _CONSENTCONFIG.fields_by_name['consent_level_extractor']._serialized_options = b'\340A\001'
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._options = None
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_options = b'8\001'
  _ENCRYPTIONCONFIG.fields_by_name['timestamp_config']._options = None
  _ENCRYPTIONCONFIG.fields_by_name['timestamp_config']._serialized_options = b'\340A\002'
  _ENCRYPTIONCONFIG.fields_by_name['batch_job_group_id']._options = None
  _ENCRYPTIONCONFIG.fields_by_name['batch_job_group_id']._serialized_options = b'\340A\002'
  _TIMESTAMPCONFIG.fields_by_name['field']._options = None
  _TIMESTAMPCONFIG.fields_by_name['field']._serialized_options = b'\340A\002'
  _TIMESTAMPCONFIG.fields_by_name['format']._options = None
  _TIMESTAMPCONFIG.fields_by_name['format']._serialized_options = b'\340A\002'
  _TIMESTAMPCONFIG.fields_by_name['default_time_zone']._options = None
  _TIMESTAMPCONFIG.fields_by_name['default_time_zone']._serialized_options = b'\340A\001'
  _ENCRYPTEDDATA.fields_by_name['target']._options = None
  _ENCRYPTEDDATA.fields_by_name['target']._serialized_options = b'\340A\002'
  _ENCRYPTIONKEYSDATA.fields_by_name['target']._options = None
  _ENCRYPTIONKEYSDATA.fields_by_name['target']._serialized_options = b'\340A\002'
  _DERIVEDDATA.fields_by_name['target']._options = None
  _DERIVEDDATA.fields_by_name['target']._serialized_options = b'\340A\002'
  _DATACONTRACTREF.fields_by_name['handle']._options = None
  _DATACONTRACTREF.fields_by_name['handle']._serialized_options = b'\340A\002'
  _DATACONTRACTREF.fields_by_name['name']._options = None
  _DATACONTRACTREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _DATACONTRACTREF.fields_by_name['version']._options = None
  _DATACONTRACTREF.fields_by_name['version']._serialized_options = b'\340A\002'
  _DATACONTRACT_PIIFIELDSENTRY._options = None
  _DATACONTRACT_PIIFIELDSENTRY._serialized_options = b'8\001'
  _DATACONTRACT.fields_by_name['id']._options = None
  _DATACONTRACT.fields_by_name['id']._serialized_options = b'\340A\002'
  _DATACONTRACT.fields_by_name['ref']._options = None
  _DATACONTRACT.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DATACONTRACT.fields_by_name['state']._options = None
  _DATACONTRACT.fields_by_name['state']._serialized_options = b'\340A\003'
  _DATACONTRACT.fields_by_name['event_sequence_field']._options = None
  _DATACONTRACT.fields_by_name['event_sequence_field']._serialized_options = b'\340A\002'
  _DATACONTRACT.fields_by_name['definition']._options = None
  _DATACONTRACT.fields_by_name['definition']._serialized_options = b'\340A\002'
  _DATACONTRACT.fields_by_name['fingerprint']._options = None
  _DATACONTRACT.fields_by_name['fingerprint']._serialized_options = b'\340A\003'
  _DATACONTRACTMETADATA.fields_by_name['title']._options = None
  _DATACONTRACTMETADATA.fields_by_name['title']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['description']._options = None
  _DATACONTRACTMETADATA.fields_by_name['description']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['create_time']._options = None
  _DATACONTRACTMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _DATACONTRACTMETADATA.fields_by_name['labels']._options = None
  _DATACONTRACTMETADATA.fields_by_name['labels']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['domains']._options = None
  _DATACONTRACTMETADATA.fields_by_name['domains']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['industries']._options = None
  _DATACONTRACTMETADATA.fields_by_name['industries']._serialized_options = b'\340A\001'
  _BATCHJOBSTATETYPE._serialized_start=11823
  _BATCHJOBSTATETYPE._serialized_end=11964
  _CONSENTLEVELTYPE._serialized_start=11966
  _CONSENTLEVELTYPE._serialized_end=12050
  _SINKTYPE._serialized_start=12052
  _SINKTYPE._serialized_end=12113
  _AUTHMECHANISM._serialized_start=12115
  _AUTHMECHANISM._serialized_end=12192
  _SCHEMATYPE._serialized_start=12194
  _SCHEMATYPE._serialized_end=12261
  _SIMPLESCHEMANODETYPE._serialized_start=12264
  _SIMPLESCHEMANODETYPE._serialized_end=12396
  _FILTERPUBLICPRIVATE._serialized_start=12398
  _FILTERPUBLICPRIVATE._serialized_end=12493
  _STREAM._serialized_start=205
  _STREAM._serialized_end=668
  _EXTENDEDSTREAM._serialized_start=670
  _EXTENDEDSTREAM._serialized_end=788
  _EXTENDEDSTREAMGROUP._serialized_start=791
  _EXTENDEDSTREAMGROUP._serialized_end=950
  _MASKEDFIELDS._serialized_start=953
  _MASKEDFIELDS._serialized_end=1234
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_start=1088
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_end=1195
  _MASKEDFIELDS_PATTERNLIST._serialized_start=1197
  _MASKEDFIELDS_PATTERNLIST._serialized_end=1234
  _LIMITS._serialized_start=1236
  _LIMITS._serialized_end=1295
  _KEYSTREAM._serialized_start=1297
  _KEYSTREAM._serialized_end=1416
  _STREAMREF._serialized_start=1418
  _STREAMREF._serialized_end=1497
  _KEYSTREAMREF._serialized_start=1499
  _KEYSTREAMREF._serialized_end=1581
  _CREDENTIALS._serialized_start=1583
  _CREDENTIALS._serialized_end=1697
  _SINK._serialized_start=1700
  _SINK._serialized_end=1900
  _SINKREF._serialized_start=1902
  _SINKREF._serialized_end=1959
  _BUCKETCONFIG._serialized_start=1961
  _BUCKETCONFIG._serialized_end=2052
  _DATACONNECTOR._serialized_start=2055
  _DATACONNECTOR._serialized_end=2522
  _DATACONNECTORREF._serialized_start=2524
  _DATACONNECTORREF._serialized_end=2600
  _DATACONNECTORDEPENDENTENTITIES._serialized_start=2603
  _DATACONNECTORDEPENDENTENTITIES._serialized_end=2763
  _AWSS3BUCKETLOCATION._serialized_start=2765
  _AWSS3BUCKETLOCATION._serialized_end=2868
  _GOOGLECLOUDSTORAGEBUCKETLOCATION._serialized_start=2870
  _GOOGLECLOUDSTORAGEBUCKETLOCATION._serialized_end=2956
  _AZUREBLOBSTORAGECONTAINERLOCATION._serialized_start=2959
  _AZUREBLOBSTORAGECONTAINERLOCATION._serialized_end=3154
  _AZURECLIENTSECRETCREDENTIAL._serialized_start=3156
  _AZURECLIENTSECRETCREDENTIAL._serialized_end=3261
  _DATATYPE._serialized_start=3263
  _DATATYPE._serialized_end=3341
  _CSVCONFIG._serialized_start=3343
  _CSVCONFIG._serialized_end=3371
  _BATCHEXPORTER._serialized_start=3374
  _BATCHEXPORTER._serialized_end=3826
  _EXTENDEDBATCHEXPORTER._serialized_start=3828
  _EXTENDEDBATCHEXPORTER._serialized_end=3942
  _BATCHEXPORTERREF._serialized_start=3944
  _BATCHEXPORTERREF._serialized_end=4030
  _KAFKACLUSTER._serialized_start=4033
  _KAFKACLUSTER._serialized_end=4235
  _KAFKACLUSTERREF._serialized_start=4237
  _KAFKACLUSTERREF._serialized_end=4322
  _KAFKAEXPORTER._serialized_start=4325
  _KAFKAEXPORTER._serialized_end=4596
  _KAFKAEXPORTERREF._serialized_start=4598
  _KAFKAEXPORTERREF._serialized_end=4684
  _KAFKAEXPORTERTARGET._serialized_start=4687
  _KAFKAEXPORTERTARGET._serialized_end=4842
  _KAFKAUSER._serialized_start=4845
  _KAFKAUSER._serialized_end=5095
  _KAFKAUSERREF._serialized_start=5097
  _KAFKAUSERREF._serialized_end=5179
  _CONSENTLEVELS._serialized_start=5181
  _CONSENTLEVELS._serialized_end=5220
  _CONSENTLEVELMAPPING._serialized_start=5222
  _CONSENTLEVELMAPPING._serialized_end=5333
  _CONSENTLEVELMAPPINGREF._serialized_start=5335
  _CONSENTLEVELMAPPINGREF._serialized_end=5428
  _WINDOWEDEVENTCOUNT._serialized_start=5431
  _WINDOWEDEVENTCOUNT._serialized_end=5581
  _SCHEMAREF._serialized_start=5584
  _SCHEMAREF._serialized_end=5724
  _SCHEMA._serialized_start=5727
  _SCHEMA._serialized_end=6322
  _SCHEMA_SIMPLESCHEMADEFINITION._serialized_start=6087
  _SCHEMA_SIMPLESCHEMADEFINITION._serialized_end=6238
  _SCHEMA_STATE._serialized_start=6240
  _SCHEMA_STATE._serialized_end=6322
  _SIMPLESCHEMANODE._serialized_start=6325
  _SIMPLESCHEMANODE._serialized_end=6552
  _SCHEMAMETADATA._serialized_start=6555
  _SCHEMAMETADATA._serialized_end=6798
  _EVENTCONTRACTREF._serialized_start=6800
  _EVENTCONTRACTREF._serialized_end=6880
  _EVENTCONTRACT._serialized_start=6883
  _EVENTCONTRACT._serialized_end=7498
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_start=7366
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_end=7414
  _EVENTCONTRACT_STATE._serialized_start=6240
  _EVENTCONTRACT_STATE._serialized_end=6322
  _EVENTCONTRACTMETADATA._serialized_start=7501
  _EVENTCONTRACTMETADATA._serialized_end=7751
  _LABEL._serialized_start=7753
  _LABEL._serialized_end=7798
  _VALIDATION._serialized_start=7800
  _VALIDATION._serialized_end=7871
  _STREAMTREE._serialized_start=7874
  _STREAMTREE._serialized_end=8196
  _SINKTREE._serialized_start=8199
  _SINKTREE._serialized_end=8336
  _BATCHJOB._serialized_start=8339
  _BATCHJOB._serialized_end=8995
  _EXTENDEDBATCHJOB._serialized_start=8997
  _EXTENDEDBATCHJOB._serialized_end=9073
  _BATCHJOBREF._serialized_start=9075
  _BATCHJOBREF._serialized_end=9154
  _BATCHJOBSTATE._serialized_start=9157
  _BATCHJOBSTATE._serialized_end=9315
  _DATACONNECTORANDTYPE._serialized_start=9318
  _DATACONNECTORANDTYPE._serialized_end=9533
  _CONSENTCONFIG._serialized_start=9536
  _CONSENTCONFIG._serialized_end=9678
  _CONSENTLEVELEXTRACTOR._serialized_start=9681
  _CONSENTLEVELEXTRACTOR._serialized_end=9912
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_start=9816
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_end=9912
  _ENCRYPTIONCONFIG._serialized_start=9915
  _ENCRYPTIONCONFIG._serialized_end=10043
  _TIMESTAMPCONFIG._serialized_start=10045
  _TIMESTAMPCONFIG._serialized_end=10158
  _ENCRYPTEDDATA._serialized_start=10160
  _ENCRYPTEDDATA._serialized_end=10247
  _ENCRYPTIONKEYSDATA._serialized_start=10249
  _ENCRYPTIONKEYSDATA._serialized_end=10341
  _DERIVEDDATA._serialized_start=10344
  _DERIVEDDATA._serialized_end=10594
  _DATACONTRACTREF._serialized_start=10596
  _DATACONTRACTREF._serialized_end=10675
  _DATACONTRACT._serialized_start=10678
  _DATACONTRACT._serialized_end=11533
  _DATACONTRACT_PIIFIELDSENTRY._serialized_start=7366
  _DATACONTRACT_PIIFIELDSENTRY._serialized_end=7414
  _DATACONTRACT_SIMPLESCHEMADEFINITION._serialized_start=6087
  _DATACONTRACT_SIMPLESCHEMADEFINITION._serialized_end=6238
  _DATACONTRACT_STATE._serialized_start=11451
  _DATACONTRACT_STATE._serialized_end=11533
  _DATACONTRACTMETADATA._serialized_start=11536
  _DATACONTRACTMETADATA._serialized_end=11762
  _PROJECT._serialized_start=11764
  _PROJECT._serialized_end=11820
# @@protoc_insertion_point(module_scope)
